package com.ruoyi.bst.order.service.impl;

import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.service.OrderAssembler;
import com.ruoyi.bst.orderProd.domain.OrderProdQuery;
import com.ruoyi.bst.orderProd.domain.OrderProdVO;
import com.ruoyi.bst.orderProd.service.IOrderProdService;
import com.ruoyi.bst.orderProd.service.OrderProdAssembler;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/12/18
 */
@Service
public class OrderAssemblerImpl implements OrderAssembler {

    @Autowired
    private IOrderProdService orderProdService;

    @Autowired
    private OrderProdAssembler orderProdAssembler;

    @Override
    public void assembleProdList(List<OrderVO> list, boolean assembleProcess, boolean assembleProgress) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        // 查询列表
        OrderProdQuery query = new OrderProdQuery();
        query.setOrderIds(CollectionUtils.map(list, OrderVO::getId));
        List<OrderProdVO> prodList = orderProdService.selectOrderProdList(query);

        // 拼接进度
        if (assembleProgress) {
            orderProdAssembler.assembleProgress(prodList);
        }

        // 拼接明细
        if (assembleProcess) {
            orderProdAssembler.assembleProcessList(prodList, true);
        }

        // 分组
        Map<Long, List<OrderProdVO>> group = prodList.stream().collect(Collectors.groupingBy(OrderProdVO::getOrderId));

        // 拼接
        for (OrderVO vo : list) {
            List<OrderProdVO> productList = group.get(vo.getId());
            if (productList == null) {
                productList = new ArrayList<>();
            }
            vo.setProdList(productList);
        }


    }

    @Override
    public void assembleProgress(List<OrderVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        OrderProdQuery query = new OrderProdQuery();
        query.setOrderIds(CollectionUtils.map(list, OrderVO::getId));
        query.setIsEnd(true);
        List<OrderProdVO> processList = orderProdService.selectOrderProdList(query);
        orderProdAssembler.assembleProgress(processList);

        for (OrderVO order : list) {
            OrderProdVO prod = processList.stream().filter(item -> Objects.equals(item.getOrderId(), order.getId())).findFirst().orElse(null);
            if (prod == null) {
                order.setReportNum(BigDecimal.ZERO);
                order.setStoreNum(BigDecimal.ZERO);
            } else {
                order.setFinalProdId(prod.getId());
                order.setReportNum(prod.getReportNum());
                order.setStoreNum(prod.getStoreNum());
            }
        }
    }
}
