package com.ruoyi.bst.orderProd.service.impl;

import com.ruoyi.bst.orderProd.domain.OrderProdVO;
import com.ruoyi.bst.orderProd.domain.enums.OrderProdWorkType;
import com.ruoyi.bst.orderProd.service.OrderProdAssembler;
import com.ruoyi.bst.prodProcess.domain.ProdProcess;
import com.ruoyi.bst.prodProcess.domain.ProdProcessQuery;
import com.ruoyi.bst.prodProcess.domain.ProdProcessVO;
import com.ruoyi.bst.prodProcess.service.IProdProcessService;
import com.ruoyi.bst.prodProcess.service.ProdProcessAssembler;
import com.ruoyi.bst.store.service.IStoreService;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/12/18
 */
@Service
public class OrderProdAssemblerImpl implements OrderProdAssembler {

    @Autowired
    private IProdProcessService prodProcessService;

    @Autowired
    private ProdProcessAssembler prodProcessAssembler;

    @Autowired
    private IStoreService storeService;

    @Override
    public void assembleProcessList(List<OrderProdVO> list, boolean progress) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        ProdProcessQuery query = new ProdProcessQuery();
        query.setOrderProdIds(CollectionUtils.map(list, OrderProdVO::getId));
        List<ProdProcessVO> processList = prodProcessService.selectProdProcessList(query);
        if (progress) {
            prodProcessAssembler.assembleProgress(processList);
        }
        Map<Long, List<ProdProcessVO>> group = processList.stream().collect(Collectors.groupingBy(ProdProcess::getOrderProdId));

        for (OrderProdVO prod : list) {
            List<ProdProcessVO> groupProcessList = group.get(prod.getId());
            if (groupProcessList == null) {
                groupProcessList = new ArrayList<>();
            }
            prod.setProcessList(groupProcessList);
        }

    }

    @Override
    public void assembleProgress(List<OrderProdVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        ProdProcessQuery query = new ProdProcessQuery();
        query.setOrderProdIds(CollectionUtils.map(list, OrderProdVO::getId));
        query.setIsEnd(true);
        List<ProdProcessVO> processList = prodProcessService.selectProdProcessList(query);
        prodProcessAssembler.assembleProgress(processList);

        for (OrderProdVO prod : list) {
            // 自加工
            if (OrderProdWorkType.SELF.getType().equals(prod.getWorkType())) {
                ProdProcessVO process = processList.stream().filter(item -> Objects.equals(item.getOrderProdId(), prod.getId())).findFirst().orElse(null);
                if (process == null) {
                    prod.setReportNum(BigDecimal.ZERO);
                    prod.setStoreNum(BigDecimal.ZERO);
                } else {
                    prod.setFinalProcessId(process.getId());
                    prod.setReportNum(process.getReportNum());
                    prod.setStoreNum(process.getStoreNum());
                }
            }
            // 外派
            else {
                prod.setReportNum(prod.getNum());
                prod.setStoreNum(prod.getNum());
            }
        }
    }
}
