package com.ruoyi.web.bst;

import com.ruoyi.bst.orderProd.domain.OrderProd;
import com.ruoyi.bst.orderProd.domain.OrderProdQuery;
import com.ruoyi.bst.orderProd.domain.OrderProdVO;
import com.ruoyi.bst.orderProd.service.IOrderProdService;
import com.ruoyi.bst.orderProd.service.OrderProdAssembler;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 订单产品Controller
 *
 * @author ruoyi
 * @date 2024-12-17
 */
@RestController
@RequestMapping("/bst/orderProd")
public class OrderProdController extends BaseController
{
    @Autowired
    private IOrderProdService orderProdService;

    @Autowired
    private OrderProdAssembler orderProdAssembler;

    /**
     * 查询订单产品列表
     */
    @PreAuthorize("@ss.hasPermi('bst:orderProd:list')")
    @GetMapping("/list")
    public TableDataInfo list(OrderProdQuery query)
    {
        startPage();
        startOrderBy();
        List<OrderProdVO> list = orderProdService.selectOrderProdList(query);
        orderProdAssembler.assembleProgress(list);
        if (query.getAssembleProcessList() != null && query.getAssembleProcessList()) {
            orderProdAssembler.assembleProcessList(list, true);
        }
        return getDataTable(list);
    }

    /**
     * 导出订单产品列表
     */
    @PreAuthorize("@ss.hasPermi('bst:orderProd:export')")
    @Log(title = "订单产品", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OrderProdQuery query)
    {
        List<OrderProdVO> list = orderProdService.selectOrderProdList(query);
        ExcelUtil<OrderProdVO> util = new ExcelUtil<OrderProdVO>(OrderProdVO.class);
        util.exportExcel(response, list, "订单产品数据");
    }

    /**
     * 获取订单产品详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:orderProd:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(orderProdService.selectOrderProdById(id));
    }

    /**
     * 新增订单产品
     */
    @PreAuthorize("@ss.hasPermi('bst:orderProd:add')")
    @Log(title = "订单产品", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OrderProd orderProd)
    {
        return toAjax(orderProdService.insertOrderProd(orderProd));
    }

    /**
     * 修改订单产品
     */
    @PreAuthorize("@ss.hasPermi('bst:orderProd:edit')")
    @Log(title = "订单产品", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OrderProd orderProd)
    {
        return toAjax(orderProdService.updateOrderProd(orderProd));
    }

    /**
     * 删除订单产品
     */
    @PreAuthorize("@ss.hasPermi('bst:orderProd:remove')")
    @Log(title = "订单产品", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(orderProdService.deleteOrderProdByIds(ids));
    }
}
